@@ -61,7 +61,7 @@ class Relationship(CogniteResource):
 
     @staticmethod
     def _validate_resource_type(resource_type):
-        _RESOURCE_TYPES = {"asset", "timeseries", "file", "event", "sequence"}
+        _RESOURCE_TYPES = {"asset", "timeseries", "file", "event", "sequence", "geospatial"}
         if resource_type.lower() not in _RESOURCE_TYPES:
             raise TypeError("Invalid source or target '{}' in relationship".format(resource_type))
 
